==> knative-model-4.6.2-sources.jar: io/fabric8/knative/serving/v1alpha1/RouteSpecFluentImpl.java <==
package io.fabric8.knative.serving.v1alpha1;

import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import io.fabric8.kubernetes.api.builder.Predicate;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Long;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;

public class RouteSpecFluentImpl<A extends io.fabric8.knative.serving.v1alpha1.RouteSpecFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.knative.serving.v1alpha1.RouteSpecFluent<A>{

    private Long generation;
    private List<io.fabric8.knative.serving.v1alpha1.TrafficTargetBuilder> traffic;

    public RouteSpecFluentImpl(){
    }
    public RouteSpecFluentImpl(io.fabric8.knative.serving.v1alpha1.RouteSpec instance){
            this.withGeneration(instance.getGeneration()); 
            this.withTraffic(instance.getTraffic()); 
    }

    public Long getGeneration(){
            return this.generation;
    }

    public A withGeneration(Long generation){
            this.generation=generation; return (A) this;
    }

    public Boolean hasGeneration(){
            return this.generation != null;
    }

    public A addToTraffic(int index,io.fabric8.knative.serving.v1alpha1.TrafficTarget item){
            if (this.traffic == null) {this.traffic = new ArrayList<io.fabric8.knative.serving.v1alpha1.TrafficTargetBuilder>();}
            io.fabric8.knative.serving.v1alpha1.TrafficTargetBuilder builder = new io.fabric8.knative.serving.v1alpha1.TrafficTargetBuilder(item);_visitables.get("traffic").add(index >= 0 ? index : _visitables.get("traffic").size(), builder);this.traffic.add(index >= 0 ? index : traffic.size(), builder); return (A)this;
    }

    public A setToTraffic(int index,io.fabric8.knative.serving.v1alpha1.TrafficTarget item){
            if (this.traffic == null) {this.traffic = new ArrayList<io.fabric8.knative.serving.v1alpha1.TrafficTargetBuilder>();}
            io.fabric8.knative.serving.v1alpha1.TrafficTargetBuilder builder = new io.fabric8.knative.serving.v1alpha1.TrafficTargetBuilder(item);
            if (index < 0 || index >= _visitables.get("traffic").size()) { _visitables.get("traffic").add(builder); } else { _visitables.get("traffic").set(index, builder);}
            if (index < 0 || index >= traffic.size()) { traffic.add(builder); } else { traffic.set(index, builder);}
             return (A)this;
    }

    public A addToTraffic(io.fabric8.knative.serving.v1alpha1.TrafficTarget... items){
            if (this.traffic == null) {this.traffic = new ArrayList<io.fabric8.knative.serving.v1alpha1.TrafficTargetBuilder>();}
            for (io.fabric8.knative.serving.v1alpha1.TrafficTarget item : items) {io.fabric8.knative.serving.v1alpha1.TrafficTargetBuilder builder = new io.fabric8.knative.serving.v1alpha1.TrafficTargetBuilder(item);_visitables.get("traffic").add(builder);this.traffic.add(builder);} return (A)this;
    }

    public A addAllToTraffic(Collection<io.fabric8.knative.serving.v1alpha1.TrafficTarget> items){
            if (this.traffic == null) {this.traffic = new ArrayList<io.fabric8.knative.serving.v1alpha1.TrafficTargetBuilder>();}
            for (io.fabric8.knative.serving.v1alpha1.TrafficTarget item : items) {io.fabric8.knative.serving.v1alpha1.TrafficTargetBuilder builder = new io.fabric8.knative.serving.v1alpha1.TrafficTargetBuilder(item);_visitables.get("traffic").add(builder);this.traffic.add(builder);} return (A)this;
    }

    public A removeFromTraffic(io.fabric8.knative.serving.v1alpha1.TrafficTarget... items){
            for (io.fabric8.knative.serving.v1alpha1.TrafficTarget item : items) {io.fabric8.knative.serving.v1alpha1.TrafficTargetBuilder builder = new io.fabric8.knative.serving.v1alpha1.TrafficTargetBuilder(item);_visitables.get("traffic").remove(builder);if (this.traffic != null) {this.traffic.remove(builder);}} return (A)this;
    }

    public A removeAllFromTraffic(Collection<io.fabric8.knative.serving.v1alpha1.TrafficTarget> items){
            for (io.fabric8.knative.serving.v1alpha1.TrafficTarget item : items) {io.fabric8.knative.serving.v1alpha1.TrafficTargetBuilder builder = new io.fabric8.knative.serving.v1alpha1.TrafficTargetBuilder(item);_visitables.get("traffic").remove(builder);if (this.traffic != null) {this.traffic.remove(builder);}} return (A)this;
    }

    
/**
 * This method has been deprecated, please use method buildTraffic instead.
 * @return The buildable object.
 */
@Deprecated public List<io.fabric8.knative.serving.v1alpha1.TrafficTarget> getTraffic(){
            return build(traffic);
    }

    public List<io.fabric8.knative.serving.v1alpha1.TrafficTarget> buildTraffic(){
            return build(traffic);
    }

    public io.fabric8.knative.serving.v1alpha1.TrafficTarget buildTraffic(int index){
            return this.traffic.get(index).build();
    }

    public io.fabric8.knative.serving.v1alpha1.TrafficTarget buildFirstTraffic(){
            return this.traffic.get(0).build();
    }

    public io.fabric8.knative.serving.v1alpha1.TrafficTarget buildLastTraffic(){
            return this.traffic.get(traffic.size() - 1).build();
    }

    public io.fabric8.knative.serving.v1alpha1.TrafficTarget buildMatchingTraffic(io.fabric8.kubernetes.api.builder.Predicate<io.fabric8.knative.serving.v1alpha1.TrafficTargetBuilder> predicate){
            for (io.fabric8.knative.serving.v1alpha1.TrafficTargetBuilder item: traffic) { if(predicate.apply(item)){return item.build();} } return null;
    }

    public Boolean hasMatchingTraffic(io.fabric8.kubernetes.api.builder.Predicate<io.fabric8.knative.serving.v1alpha1.TrafficTargetBuilder> predicate){
            for (io.fabric8.knative.serving.v1alpha1.TrafficTargetBuilder item: traffic) { if(predicate.apply(item)){return true;} } return false;
    }

    public A withTraffic(List<io.fabric8.knative.serving.v1alpha1.TrafficTarget> traffic){
            if (this.traffic != null) { _visitables.get("traffic").removeAll(this.traffic);}
            if (traffic != null) {this.traffic = new ArrayList<io.fabric8.knative.serving.v1alpha1.TrafficTargetBuilder>(); for (io.fabric8.knative.serving.v1alpha1.TrafficTarget item : traffic){this.addToTraffic(item);}} else { this.traffic = new ArrayList<io.fabric8.knative.serving.v1alpha1.TrafficTargetBuilder>();} return (A) this;
    }

    public A withTraffic(io.fabric8.knative.serving.v1alpha1.TrafficTarget... traffic){
            if (this.traffic != null) {this.traffic.clear();}
            if (traffic != null) {for (io.fabric8.knative.serving.v1alpha1.TrafficTarget item :traffic){ this.addToTraffic(item);}} return (A) this;
    }

    public Boolean hasTraffic(){
            return traffic != null && !traffic.isEmpty();
    }

    public RouteSpecFluent.TrafficNested<A> addNewTraffic(){
            return new TrafficNestedImpl();
    }

    public RouteSpecFluent.TrafficNested<A> addNewTrafficLike(io.fabric8.knative.serving.v1alpha1.TrafficTarget item){
            return new TrafficNestedImpl(-1, item);
    }

    public RouteSpecFluent.TrafficNested<A> setNewTrafficLike(int index,io.fabric8.knative.serving.v1alpha1.TrafficTarget item){
            return new TrafficNestedImpl(index, item);
    }

    public RouteSpecFluent.TrafficNested<A> editTraffic(int index){
            if (traffic.size() <= index) throw new RuntimeException("Can't edit traffic. Index exceeds size.");
            return setNewTrafficLike(index, buildTraffic(index));
    }

    public RouteSpecFluent.TrafficNested<A> editFirstTraffic(){
            if (traffic.size() == 0) throw new RuntimeException("Can't edit first traffic. The list is empty.");
            return setNewTrafficLike(0, buildTraffic(0));
    }

    public RouteSpecFluent.TrafficNested<A> editLastTraffic(){
            int index = traffic.size() - 1;
            if (index < 0) throw new RuntimeException("Can't edit last traffic. The list is empty.");
            return setNewTrafficLike(index, buildTraffic(index));
    }

    public RouteSpecFluent.TrafficNested<A> editMatchingTraffic(io.fabric8.kubernetes.api.builder.Predicate<io.fabric8.knative.serving.v1alpha1.TrafficTargetBuilder> predicate){
            int index = -1;
            for (int i=0;i<traffic.size();i++) { 
            if (predicate.apply(traffic.get(i))) {index = i; break;}
            } 
            if (index < 0) throw new RuntimeException("Can't edit matching traffic. No match found.");
            return setNewTrafficLike(index, buildTraffic(index));
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            RouteSpecFluentImpl that = (RouteSpecFluentImpl) o;
            if (generation != null ? !generation.equals(that.generation) :that.generation != null) return false;
            if (traffic != null ? !traffic.equals(that.traffic) :that.traffic != null) return false;
            return true;
    }


    public class TrafficNestedImpl<N> extends io.fabric8.knative.serving.v1alpha1.TrafficTargetFluentImpl<RouteSpecFluent.TrafficNested<N>> implements RouteSpecFluent.TrafficNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{

            private final io.fabric8.knative.serving.v1alpha1.TrafficTargetBuilder builder;
        private final int index;
    
            TrafficNestedImpl(int index,io.fabric8.knative.serving.v1alpha1.TrafficTarget item){
                    this.index = index;
                    this.builder = new io.fabric8.knative.serving.v1alpha1.TrafficTargetBuilder(this, item);
            }
            TrafficNestedImpl(){
                    this.index = -1;
                    this.builder = new io.fabric8.knative.serving.v1alpha1.TrafficTargetBuilder(this);
            }
    
    public N and(){
            return (N) RouteSpecFluentImpl.this.setToTraffic(index, builder.build());
    }
    public N endTraffic(){
            return and();
    }

}


}

==> knative-model-4.10.0-sources.jar: io/fabric8/knative/serving/v1alpha1/RouteSpecFluentImpl.java <==
package io.fabric8.knative.serving.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import io.fabric8.kubernetes.api.builder.Predicate;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;

public class RouteSpecFluentImpl<A extends io.fabric8.knative.serving.v1alpha1.RouteSpecFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.knative.serving.v1alpha1.RouteSpecFluent<A>{

    private Long generation;
    private List<io.fabric8.knative.serving.v1alpha1.TrafficTargetBuilder> traffic;

    public RouteSpecFluentImpl(){
    }
    public RouteSpecFluentImpl(io.fabric8.knative.serving.v1alpha1.RouteSpec instance){
            this.withGeneration(instance.getGeneration()); 
            this.withTraffic(instance.getTraffic()); 
    }

    public Long getGeneration(){
            return this.generation;
    }

    public A withGeneration(Long generation){
            this.generation=generation; return (A) this;
    }

    public Boolean hasGeneration(){
            return this.generation != null;
    }

    public A addToTraffic(int index,io.fabric8.knative.serving.v1alpha1.TrafficTarget item){
            if (this.traffic == null) {this.traffic = new ArrayList<io.fabric8.knative.serving.v1alpha1.TrafficTargetBuilder>();}
            io.fabric8.knative.serving.v1alpha1.TrafficTargetBuilder builder = new io.fabric8.knative.serving.v1alpha1.TrafficTargetBuilder(item);_visitables.get("traffic").add(index >= 0 ? index : _visitables.get("traffic").size(), builder);this.traffic.add(index >= 0 ? index : traffic.size(), builder); return (A)this;
    }

    public A setToTraffic(int index,io.fabric8.knative.serving.v1alpha1.TrafficTarget item){
            if (this.traffic == null) {this.traffic = new ArrayList<io.fabric8.knative.serving.v1alpha1.TrafficTargetBuilder>();}
            io.fabric8.knative.serving.v1alpha1.TrafficTargetBuilder builder = new io.fabric8.knative.serving.v1alpha1.TrafficTargetBuilder(item);
            if (index < 0 || index >= _visitables.get("traffic").size()) { _visitables.get("traffic").add(builder); } else { _visitables.get("traffic").set(index, builder);}
            if (index < 0 || index >= traffic.size()) { traffic.add(builder); } else { traffic.set(index, builder);}
             return (A)this;
    }

    public A addToTraffic(io.fabric8.knative.serving.v1alpha1.TrafficTarget... items){
            if (this.traffic == null) {this.traffic = new ArrayList<io.fabric8.knative.serving.v1alpha1.TrafficTargetBuilder>();}
            for (io.fabric8.knative.serving.v1alpha1.TrafficTarget item : items) {io.fabric8.knative.serving.v1alpha1.TrafficTargetBuilder builder = new io.fabric8.knative.serving.v1alpha1.TrafficTargetBuilder(item);_visitables.get("traffic").add(builder);this.traffic.add(builder);} return (A)this;
    }

    public A addAllToTraffic(Collection<io.fabric8.knative.serving.v1alpha1.TrafficTarget> items){
            if (this.traffic == null) {this.traffic = new ArrayList<io.fabric8.knative.serving.v1alpha1.TrafficTargetBuilder>();}
            for (io.fabric8.knative.serving.v1alpha1.TrafficTarget item : items) {io.fabric8.knative.serving.v1alpha1.TrafficTargetBuilder builder = new io.fabric8.knative.serving.v1alpha1.TrafficTargetBuilder(item);_visitables.get("traffic").add(builder);this.traffic.add(builder);} return (A)this;
    }

    public A removeFromTraffic(io.fabric8.knative.serving.v1alpha1.TrafficTarget... items){
            for (io.fabric8.knative.serving.v1alpha1.TrafficTarget item : items) {io.fabric8.knative.serving.v1alpha1.TrafficTargetBuilder builder = new io.fabric8.knative.serving.v1alpha1.TrafficTargetBuilder(item);_visitables.get("traffic").remove(builder);if (this.traffic != null) {this.traffic.remove(builder);}} return (A)this;
    }

    public A removeAllFromTraffic(Collection<io.fabric8.knative.serving.v1alpha1.TrafficTarget> items){
            for (io.fabric8.knative.serving.v1alpha1.TrafficTarget item : items) {io.fabric8.knative.serving.v1alpha1.TrafficTargetBuilder builder = new io.fabric8.knative.serving.v1alpha1.TrafficTargetBuilder(item);_visitables.get("traffic").remove(builder);if (this.traffic != null) {this.traffic.remove(builder);}} return (A)this;
    }

    public A removeMatchingFromTraffic(io.fabric8.kubernetes.api.builder.Predicate<io.fabric8.knative.serving.v1alpha1.TrafficTargetBuilder> predicate){
            if (traffic == null) return (A) this;
            final Iterator<io.fabric8.knative.serving.v1alpha1.TrafficTargetBuilder> each = traffic.iterator();
            final List visitables = _visitables.get("traffic");
            while (each.hasNext()) {
              io.fabric8.knative.serving.v1alpha1.TrafficTargetBuilder builder = each.next();
              if (predicate.apply(builder)) {
                visitables.remove(builder);
                each.remove();
              }
            }
            return (A)this;
    }

    
/**
 * This method has been deprecated, please use method buildTraffic instead.
 * @return The buildable object.
 */
@java.lang.Deprecated public List<io.fabric8.knative.serving.v1alpha1.TrafficTarget> getTraffic(){
            return build(traffic);
    }

    public List<io.fabric8.knative.serving.v1alpha1.TrafficTarget> buildTraffic(){
            return build(traffic);
    }

    public io.fabric8.knative.serving.v1alpha1.TrafficTarget buildTraffic(int index){
            return this.traffic.get(index).build();
    }

    public io.fabric8.knative.serving.v1alpha1.TrafficTarget buildFirstTraffic(){
            return this.traffic.get(0).build();
    }

    public io.fabric8.knative.serving.v1alpha1.TrafficTarget buildLastTraffic(){
            return this.traffic.get(traffic.size() - 1).build();
    }

    public io.fabric8.knative.serving.v1alpha1.TrafficTarget buildMatchingTraffic(io.fabric8.kubernetes.api.builder.Predicate<io.fabric8.knative.serving.v1alpha1.TrafficTargetBuilder> predicate){
            for (io.fabric8.knative.serving.v1alpha1.TrafficTargetBuilder item: traffic) { if(predicate.apply(item)){ return item.build();} } return null;
    }

    public Boolean hasMatchingTraffic(io.fabric8.kubernetes.api.builder.Predicate<io.fabric8.knative.serving.v1alpha1.TrafficTargetBuilder> predicate){
            for (io.fabric8.knative.serving.v1alpha1.TrafficTargetBuilder item: traffic) { if(predicate.apply(item)){ return true;} } return false;
    }

    public A withTraffic(List<io.fabric8.knative.serving.v1alpha1.TrafficTarget> traffic){
            if (this.traffic != null) { _visitables.get("traffic").removeAll(this.traffic);}
            if (traffic != null) {this.traffic = new ArrayList<io.fabric8.knative.serving.v1alpha1.TrafficTargetBuilder>(); for (io.fabric8.knative.serving.v1alpha1.TrafficTarget item : traffic){this.addToTraffic(item);}} else { this.traffic = null;} return (A) this;
    }

    public A withTraffic(io.fabric8.knative.serving.v1alpha1.TrafficTarget... traffic){
            if (this.traffic != null) {this.traffic.clear();}
            if (traffic != null) {for (io.fabric8.knative.serving.v1alpha1.TrafficTarget item :traffic){ this.addToTraffic(item);}} return (A) this;
    }

    public Boolean hasTraffic(){
            return traffic != null && !traffic.isEmpty();
    }

    public RouteSpecFluent.TrafficNested<A> addNewTraffic(){
            return new TrafficNestedImpl();
    }

    public RouteSpecFluent.TrafficNested<A> addNewTrafficLike(io.fabric8.knative.serving.v1alpha1.TrafficTarget item){
            return new TrafficNestedImpl(-1, item);
    }

    public RouteSpecFluent.TrafficNested<A> setNewTrafficLike(int index,io.fabric8.knative.serving.v1alpha1.TrafficTarget item){
            return new TrafficNestedImpl(index, item);
    }

    public RouteSpecFluent.TrafficNested<A> editTraffic(int index){
            if (traffic.size() <= index) throw new RuntimeException("Can't edit traffic. Index exceeds size.");
            return setNewTrafficLike(index, buildTraffic(index));
    }

    public RouteSpecFluent.TrafficNested<A> editFirstTraffic(){
            if (traffic.size() == 0) throw new RuntimeException("Can't edit first traffic. The list is empty.");
            return setNewTrafficLike(0, buildTraffic(0));
    }

    public RouteSpecFluent.TrafficNested<A> editLastTraffic(){
            int index = traffic.size() - 1;
            if (index < 0) throw new RuntimeException("Can't edit last traffic. The list is empty.");
            return setNewTrafficLike(index, buildTraffic(index));
    }

    public RouteSpecFluent.TrafficNested<A> editMatchingTraffic(io.fabric8.kubernetes.api.builder.Predicate<io.fabric8.knative.serving.v1alpha1.TrafficTargetBuilder> predicate){
            int index = -1;
            for (int i=0;i<traffic.size();i++) { 
            if (predicate.apply(traffic.get(i))) {index = i; break;}
            } 
            if (index < 0) throw new RuntimeException("Can't edit matching traffic. No match found.");
            return setNewTrafficLike(index, buildTraffic(index));
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            RouteSpecFluentImpl that = (RouteSpecFluentImpl) o;
            if (generation != null ? !generation.equals(that.generation) :that.generation != null) return false;
            if (traffic != null ? !traffic.equals(that.traffic) :that.traffic != null) return false;
            return true;
    }


    public class TrafficNestedImpl<N> extends io.fabric8.knative.serving.v1alpha1.TrafficTargetFluentImpl<RouteSpecFluent.TrafficNested<N>> implements RouteSpecFluent.TrafficNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{

            private final io.fabric8.knative.serving.v1alpha1.TrafficTargetBuilder builder;
        private final int index;
    
            TrafficNestedImpl(int index,io.fabric8.knative.serving.v1alpha1.TrafficTarget item){
                    this.index = index;
                    this.builder = new io.fabric8.knative.serving.v1alpha1.TrafficTargetBuilder(this, item);
            }
            TrafficNestedImpl(){
                    this.index = -1;
                    this.builder = new io.fabric8.knative.serving.v1alpha1.TrafficTargetBuilder(this);
            }
    
    public N and(){
            return (N) RouteSpecFluentImpl.this.setToTraffic(index,builder.build());
    }
    public N endTraffic(){
            return and();
    }

}


}
